import objectdraw.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JPanel;

/*
 * Example FallingBallComboButton: just one Swing JButton
 * to create a ball, but select speed based on the contents
 * of a JComboBox.
 *
 * Jim Teresco, The College of Saint Rose, Fall 2013
 * Based on example from Williams College CS 134.
 *
 * $Id: FallingBallComboButton.java 2221 2013-10-22 02:48:35Z terescoj $
 */

public class FallingBallComboButton extends WindowController implements ActionListener {
    private static final int SLOW_SPEED = 2;
    private static final int MEDIUM_SPEED = 5;
    private static final int FAST_SPEED = 10;

    // we'll be using a JComboBox in begin and in
    // actionPerformed, so we need to remember it.
    private JComboBox speedMenu;
    
    public void begin() {

        setSize(500, 500);

        // We still need our content pane
        Container contentPane = getContentPane();

        // A JPanel, in which we will group together our JButton
        // and JComboBox
        JPanel southPanel = new JPanel();

        // Next, we'll create just one button and add it to our
        // JPanel.
        JButton createBallButton = new JButton("Drop Ball");
        southPanel.add(createBallButton);

        // construct a JComboBox
        speedMenu = new JComboBox();
        // and some menu entries therein
        speedMenu.addItem("Slow");
        speedMenu.addItem("Medium");
        speedMenu.addItem("Fast");

        // which one is selected when we start?
        speedMenu.setSelectedItem("Medium");
        
        // and put our JComboBox into our JPanel
        southPanel.add(speedMenu);

        // now, we add the JPanel (which contains our JButton
        // and JComboBox) to the content pane, in the south
        contentPane.add(southPanel, BorderLayout.SOUTH);

        // add our action listener
        createBallButton.addActionListener(this);

        // put at end of all methods that change the layout
        contentPane.validate();
    }

    // actionPerformed method now doesn't need to check
    // which button was pressed - there's just the one.
    // But it does need to check the currently selected
    // menu item
    public void actionPerformed(ActionEvent e) {

        double speed;
        // this will return the selected item from the JComboBox
        Object selectedSpeed = speedMenu.getSelectedItem();

        // now we see which one it is by comparing to the Strings
        // we used when we added the menu items above.
        if (selectedSpeed.equals("Slow")) {
            speed = SLOW_SPEED;
        } 
        else if (selectedSpeed.equals("Medium")) {
            speed = MEDIUM_SPEED;
        } 
        else {  // "Fast" is the only other possibility
            speed = FAST_SPEED;
        }
        new Ball(new Location(200, 0), speed, canvas);
    }
}
